==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF13S.sql <==
/****************************************************************************/
/* GF13 ( ｶﾚﾝﾀﾞｰﾌｧｲﾙ )                                                      */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF13 (
   CDJGS    VARCHAR2 ( 10 )                 NOT NULL            /*  10 事業所ｺｰﾄﾞ   */
 , YYYYMM   VARCHAR2 (  6 )                 NOT NULL            /*  20 年月         */
 , DY1      VARCHAR2 (  1 )                                     /*  30 1日          */
 , DY2      VARCHAR2 (  1 )                                     /*  40 2日          */
 , DY3      VARCHAR2 (  1 )                                     /*  50 3日          */
 , DY4      VARCHAR2 (  1 )                                     /*  60 4日          */
 , DY5      VARCHAR2 (  1 )                                     /*  70 5日          */
 , DY6      VARCHAR2 (  1 )                                     /*  80 6日          */
 , DY7      VARCHAR2 (  1 )                                     /*  90 7日          */
 , DY8      VARCHAR2 (  1 )                                     /* 100 8日          */
 , DY9      VARCHAR2 (  1 )                                     /* 110 9日          */
 , DY10     VARCHAR2 (  1 )                                     /* 120 10日         */
 , DY11     VARCHAR2 (  1 )                                     /* 130 11日         */
 , DY12     VARCHAR2 (  1 )                                     /* 140 12日         */
 , DY13     VARCHAR2 (  1 )                                     /* 150 13日         */
 , DY14     VARCHAR2 (  1 )                                     /* 160 14日         */
 , DY15     VARCHAR2 (  1 )                                     /* 170 15日         */
 , DY16     VARCHAR2 (  1 )                                     /* 180 16日         */
 , DY17     VARCHAR2 (  1 )                                     /* 190 17日         */
 , DY18     VARCHAR2 (  1 )                                     /* 200 18日         */
 , DY19     VARCHAR2 (  1 )                                     /* 210 19日         */
 , DY20     VARCHAR2 (  1 )                                     /* 220 20日         */
 , DY21     VARCHAR2 (  1 )                                     /* 230 21日         */
 , DY22     VARCHAR2 (  1 )                                     /* 240 22日         */
 , DY23     VARCHAR2 (  1 )                                     /* 250 23日         */
 , DY24     VARCHAR2 (  1 )                                     /* 260 24日         */
 , DY25     VARCHAR2 (  1 )                                     /* 270 25日         */
 , DY26     VARCHAR2 (  1 )                                     /* 280 26日         */
 , DY27     VARCHAR2 (  1 )                                     /* 290 27日         */
 , DY28     VARCHAR2 (  1 )                                     /* 300 28日         */
 , DY29     VARCHAR2 (  1 )                                     /* 310 29日         */
 , DY30     VARCHAR2 (  1 )                                     /* 320 30日         */
 , DY31     VARCHAR2 (  1 )                                     /* 330 31日         */
 , UNIQ     NUMBER   (  9 )     DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ      VARCHAR2 (  1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET    VARCHAR2 ( 14 )                                     /* 820 登録日時     */
 , PGSET    VARCHAR2 ( 10 )                                     /* 830 作成PG       */
 , PGPSET   VARCHAR2 ( 10 )                                     /* 840 作成親PG     */
 , USRSET   VARCHAR2 ( 10 )                                     /* 850 作成社員     */
 , DYUPD    VARCHAR2 ( 14 )                                     /* 860 更新日時     */
 , PGUPD    VARCHAR2 ( 10 )                                     /* 870 更新PG       */
 , PGPUPD   VARCHAR2 ( 10 )                                     /* 880 更新親PG     */
 , USRUPD   VARCHAR2 ( 10 )                                     /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF13S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF13T00 
  BEFORE INSERT ON GF13
  FOR EACH ROW 
  BEGIN 
    SELECT GF13S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF13S.sql <==
/****************************************************************************/
/* GF13 ( ｶﾚﾝﾀﾞｰﾌｧｲﾙ )                                                      */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF13 (
   CDJGS    VARCHAR2 ( 10 )                 NOT NULL            /*  10 事業所ｺｰﾄﾞ   */
 , YYYYMM   VARCHAR2 (  6 )                 NOT NULL            /*  20 年月         */
 , DY1      VARCHAR2 (  1 )                                     /*  30 1日          */
 , DY2      VARCHAR2 (  1 )                                     /*  40 2日          */
 , DY3      VARCHAR2 (  1 )                                     /*  50 3日          */
 , DY4      VARCHAR2 (  1 )                                     /*  60 4日          */
 , DY5      VARCHAR2 (  1 )                                     /*  70 5日          */
 , DY6      VARCHAR2 (  1 )                                     /*  80 6日          */
 , DY7      VARCHAR2 (  1 )                                     /*  90 7日          */
 , DY8      VARCHAR2 (  1 )                                     /* 100 8日          */
 , DY9      VARCHAR2 (  1 )                                     /* 110 9日          */
 , DY10     VARCHAR2 (  1 )                                     /* 120 10日         */
 , DY11     VARCHAR2 (  1 )                                     /* 130 11日         */
 , DY12     VARCHAR2 (  1 )                                     /* 140 12日         */
 , DY13     VARCHAR2 (  1 )                                     /* 150 13日         */
 , DY14     VARCHAR2 (  1 )                                     /* 160 14日         */
 , DY15     VARCHAR2 (  1 )                                     /* 170 15日         */
 , DY16     VARCHAR2 (  1 )                                     /* 180 16日         */
 , DY17     VARCHAR2 (  1 )                                     /* 190 17日         */
 , DY18     VARCHAR2 (  1 )                                     /* 200 18日         */
 , DY19     VARCHAR2 (  1 )                                     /* 210 19日         */
 , DY20     VARCHAR2 (  1 )                                     /* 220 20日         */
 , DY21     VARCHAR2 (  1 )                                     /* 230 21日         */
 , DY22     VARCHAR2 (  1 )                                     /* 240 22日         */
 , DY23     VARCHAR2 (  1 )                                     /* 250 23日         */
 , DY24     VARCHAR2 (  1 )                                     /* 260 24日         */
 , DY25     VARCHAR2 (  1 )                                     /* 270 25日         */
 , DY26     VARCHAR2 (  1 )                                     /* 280 26日         */
 , DY27     VARCHAR2 (  1 )                                     /* 290 27日         */
 , DY28     VARCHAR2 (  1 )                                     /* 300 28日         */
 , DY29     VARCHAR2 (  1 )                                     /* 310 29日         */
 , DY30     VARCHAR2 (  1 )                                     /* 320 30日         */
 , DY31     VARCHAR2 (  1 )                                     /* 330 31日         */
 , UNIQ     NUMBER   (  9 )     DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ      VARCHAR2 (  1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET    VARCHAR2 ( 14 )                                     /* 820 登録日時     */
 , PGSET    VARCHAR2 ( 10 )                                     /* 830 作成PG       */
 , PGPSET   VARCHAR2 ( 10 )                                     /* 840 作成親PG     */
 , USRSET   VARCHAR2 ( 10 )                                     /* 850 作成社員     */
 , DYUPD    VARCHAR2 ( 14 )                                     /* 860 更新日時     */
 , PGUPD    VARCHAR2 ( 10 )                                     /* 870 更新PG       */
 , PGPUPD   VARCHAR2 ( 10 )                                     /* 880 更新親PG     */
 , USRUPD   VARCHAR2 ( 10 )                                     /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF13S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF13T00 
  BEFORE INSERT ON GF13
  FOR EACH ROW 
  BEGIN 
    SELECT GF13S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
